@@ -20,7 +20,7 @@ function(widget, action = c("add", "configure", "delete", "names", "cget", "near
 function(widget, items) {
 	# Set a list of values for a widget (e.g., combobox)
 	if (inherits(widget, "ttk2combobox")) {
-        # Tile combobox uses -values parameter
+        # ttk::combobox uses -values parameter
         tkconfigure(widget, values = as.character(items))
     } else {
         # Try to use the defaul method
@@ -36,7 +36,7 @@ function(widget, items) {
 function(widget, index = "end", ...) {
 	# Insert one or more items in a list
 	if (inherits(widget, "ttk2combobox")) {
-        # Tile combobox uses -values parameter
+        # ttk::combobox uses -values parameter
 		Items <- as.character(unlist(list(...)))
 		if (length(Items) < 1) return()	# Nothing to insert
 		List <- as.character(tcl(widget, "cget", "-values"))
@@ -63,7 +63,7 @@ function(widget, index = "end", ...) {
 function(widget, first, last = first) {
 	# Delete one or more items from a list
 	if (inherits(widget, "ttk2combobox")) {
-        # Tile combobox uses -values parameter
+        # ttk::combobox uses -values parameter
 		List <- as.character(tcl(widget, "cget", "-values"))
 		if (length(List) < 2 && List == "") return(List)	# The list in empty
 		if (last == "end") last <- length(List) else last <- last + 1
@@ -78,8 +78,8 @@ function(widget, first, last = first) {
 "tk2list.get" <-
 function(widget, first = 0, last = "end") {
 	# Get the list of elements in a widget (e.g., combobox)
-	if (inherits(widget, "ttk2combobox")) {
-        # Tile combobox uses -values parameter
+	if (inherits(widget, "tk2combobox")) {
+        # ttk::combobox uses -values parameter
 		List <- as.character(tcl(widget, "cget", "-values"))
 		if (length(List) < 2 && List == "") return(List)
 		if (last == "end") last <- length(List) else last <- last + 1
@@ -92,8 +92,8 @@ function(widget, first = 0, last = "end") {
 "tk2list.size" <-
 function(widget) {
 	# Get the length of the list of elements in a widget (e.g., combobox)
-	if (inherits(widget, "ttk2combobox")) {
-        # Tile combobox uses -values parameter
+	if (inherits(widget, "tk2combobox")) {
+        # ttk::combobox uses -values parameter
 		List <- as.character(tcl(widget, "cget", "-values"))
 		return(length(List))
 	} else {
@@ -105,20 +105,7 @@ function(widget) {
 function(widget, state = c("normal", "disabled", "readonly")) {
 	# Change the state of a widget
 	state <- as.character(state[1])
-	# Treatment is different, depending if the widget is a tile widget, or not
-	if (substring(class(widget)[1], 1, 3) == "ttk") {
-		# This is a tile widget
-		tkconfigure(widget, state = state)
-	} else {
-		# This is a plain Tk widget
-		if (state == "readonly") {
-			.Tcl(paste("catch {", widget$ID, " configure -editable false}",  sep = ""))
-			.Tcl(paste("catch {", widget$ID, " configure -state readonly}",  sep = ""))
-		} else {
-			.Tcl(paste("catch {", widget$ID, " configure -editable true}",  sep = ""))
-			tkconfigure(widget, state = state)
-		}
-	}
+	tkconfigure(widget, state = state)
 }
 
 "tk2insert.multi" <-
@@ -134,17 +121,13 @@ function(widget, where = "end", items) {
 }
 
 "tk2notetraverse" <- function(nb) {
-	# This function is only useful with tile widget
-	if (!is.tile()) return(FALSE)
-	tcl("ttk::notebook::enableTraversal", nb)
-	return(TRUE)
+	res <- tcl("ttk::notebook::enableTraversal", nb)
+	return(invisible(res))
 }
 
 "tk2notetab" <-
 function(nb, tab) {
-    # Different treatment, depending if it is tile or nor
-    if (inherits(nb, "ttk2notebook")) {
-        # Tile notebook
+    if (inherits(nb, "tk2notebook")) {
         # We need the tab index, so, look for it
 		ntab <- as.numeric(tcl(nb, "index", "end"))
 		if (ntab < 1) return(NULL)
@@ -165,30 +148,13 @@ function(nb, tab) {
             class(w) <- c("ttk2notetab", "tk2container", "tkwin")
             return(w)
 		} else return(NULL) # Tab not found!
-    } else if (inherits(nb, "tk2notebook")) {
-        # Plain Tk notebook
-		tab <- tclvalue(.Tcl(paste("Notebook:frame", nb$ID,
-			paste("{", tab, "}", sep = ""))))
-		if (tab == "") {
-            # This page does not exist!
-            return(NULL)
-        } else {
-            # Create a simili tkwin object referring to this page
-            w <- list()
-            w$ID <- tab
-			w$env <- new.env()
-			w$env$num.subwin <- 0
-			w$env$parent <- nb
-            class(w) <- c("tk2notetab", "tk2container", "tkwin")
-            return(w)
-        }
-    } else stop ("'nb' must be either a 'tk2notebook', or a 'ttk2notebook'")
+    } else stop ("'nb' must be a 'tk2notebook' object")
 }
 
 "tk2notetab.select" <-
 function(nb, tab) {
-    # Select a tab in a notebook, different depending if it is tile or not
-    if (inherits(nb, "ttk2notebook")) {
+    # Select a tab in a notebook
+    if (inherits(nb, "tk2notebook")) {
         # Tile notebook
 		# We need the tab index, so, look for it
 		ntab <- as.numeric(tcl(nb, "index", "end"))
@@ -203,39 +169,27 @@ function(nb, tab) {
 			tkselect(nb, tabidx)
 			return(invisible(TRUE))
 		} else return(invisible(FALSE))
-    } else if (inherits(nb, "tk2notebook")) {
-        ### TODO: would also like to raise a given page number!
-        # Plain Tk notebook
-        .Tcl(paste("Notebook:raise ", nb$ID, " {", tab[1], "}", sep = ""))
-		return(invisible(tk2notetab.text(nb) == tab))
-    } else stop ("'nb' must be either a 'tk2notebook', or a 'ttk2notebook'")
+    } else stop ("'nb' must be a 'tk2notebook' object")
 }
 
 "tk2notetab.text" <-
 function(nb) {
-    # Select a tab in a notebook, different depending if it is tile or not
-    if (inherits(nb, "ttk2notebook")) {
-        # Tile notebook
+    # Select a tab in a notebook
+    if (inherits(nb, "tk2notebook")) {
 		return(tclvalue(tcl(nb, "tab", "current", "-text")))
-    } else if (inherits(nb, "tk2notebook")) {
-        # Plain Tk notebook
-        return(tclvalue(.Tcl(paste("Notebook:current", nb$ID))))
-    } else stop ("'nb' must be either a 'tk2notebook', or a 'ttk2notebook'")
+    } else stop ("'nb' must be a 'tk2notebook' object")
 }
 
 # Themes management
 "tk2theme.elements" <- function() {
-	if (!is.tile()) return(NULL)
 	return(as.character(.Tcl("ttk::style element names")))
 }
 
 "tk2theme.list" <- function() {
-	if (!is.tile()) return(NULL)
 	return(as.character(.Tcl("ttk::style theme names")))
 }
 
 "tk2theme" <- function(theme = NULL) {
-	if (!is.tile()) return(NULL)
     if (is.null(theme)) { # Get it
         res <- getOption("tk2theme")
     } else { # Set it to theme
@@ -275,58 +229,9 @@ function() {
 	return(tclvalue(.Tcl("catch { package present Tk }")) == 0)
 }
 
-"is.tile" <-
-function() {
-	# Tile, alias ttk widgets are automatically installed under Tk >= 8.5
-	if (as.numeric(.Tcl("set tcl_version")) >= 8.5) return(TRUE)
-	# Determine if tile is loaded, and if we want to use it
-	use.tile <- getOption("tcltk2.tile")
-	if (!is.null(use.tile) && !use.tile) return(FALSE)
-	# Otherwise, look if the tile package is loaded
-	return(tclvalue(.Tcl("catch { package present tile }")) == 0)
-}
-
-"tile.load" <-
-function(warn = TRUE) {
-	if (!is.tk()) return(FALSE) # Impossible to load tile if tk is not loaded
-	if (is.tile()) return(TRUE)	# Already loaded
-
-	# We must take care of fonts synchronisation and other stuff like
-	# options(tcltk2.tile)
-
-	# First delete all Tk* fonts created in Tcl/Tk (otherwise, loading of tile fails?!)
-	tkfonts <- as.character(tkfont.names())
-	tkfonts <-  tkfonts[grep("^Tk", tkfonts)]
-	for (font in tkfonts) tkfont.delete(font)
-
-	# Try loading tile
-	if (inherits(tclRequire("tile", warn = warn), "tclObj")) {	# OK
-		# Finalize fonts
-		tk2font.setstyle(system = TRUE, default.styles = TRUE, text = TRUE)
-		# Indicate that tile is loaded
-		options(tcltk2.tile = TRUE)
-		return(TRUE)
-	} else { # Impossible to load tile (not installed on this machine?
-		# We must restore Tk fonts
-		# Look for a place to find it
-		libs <- .libPaths()
-		for (lib in libs) {
-			fontfile <- file.path(lib, "tcltk2", "tklibs", "fonts.tcl")
-			if (file.exists(fontfile)) {
-				tcl("source", fontfile)
-				break
-			}
-		}
-		# Finalize fonts
-		tk2font.setstyle(system = TRUE, default.styles = TRUE, text = TRUE)
-		options(tcltk2.tile = FALSE)
-		return(FALSE)
-	}
-}
-
-"tile.use" <-
-function(use.it = TRUE) {
-	options(tcltk2.tile = use.it)
-	# Indicate also for Tcl code what we want
-	if (use.it) .Tcl("set tile_use 1") else .Tcl("set tile_use 0")
+"is.ttk" <-
+function ()
+{
+	res <- is.tk() && as.numeric(tcl("set", "tk_version")) >= 8.5
+	return(res)
 }
